@@ -103,3 +103,9 @@ def model_from_shared_key(step):
     world.model = world.api.get_model(world.model['resource'],
         shared_username=username, shared_api_key=world.sharing_key)
     assert get_status(world.model)['code'] == FINISHED
+
+@step(r'"(.*)" field\'s name is changed to "(.*)"')
+def field_name_to_new_name(step, field_id, new_name):
+    if world.local_model.tree.fields[field_id]['name'] != new_name:
+        print world.local_model.tree.fields[field_id]['name'], new_name
+    assert world.local_model.tree.fields[field_id]['name'] == new_name
